---
name: ytree issue template
about: General ytree issue template.
title: ''
labels: ''
assignees: ''

---

<!--To help understand and resolve your issue, please use the template below.-->
<!--Delete any sections that do not apply.-->
<!--Start from scratch if you prefer.-->

### Bug report

**Bug summary**

<!--A short 1-2 sentences that succinctly describes the bug.-->

**Code for reproduction**

<!--A minimum code snippet required to reproduce the bug.-->

```python
# Paste your code here
#
#
```

**Actual outcome**

<!--The output produced by the above code: a screenshot, console, output, etc.-->

```
# If applicable, paste the console output here
#
#
```

**Expected outcome**

<!--A description of the expected outcome from the code snippet-->
<!--If this used to work in an earlier version of ytree, please note the version it used to work on-->

**Version Information**
<!--Specify your OS and versions of the relevant libraries.-->
  * Operating System:
  * Python Version:
  * ytree version:
  * Other Libraries (if applicable):

<!--Please mention how you installed yt and python, e.g., from source, pip, conda.-->
